@@ -164,7 +164,10 @@ class Many2Many(Widget):
             title=self.attrs.get('string'))
         win.screen.search_filter(quote(value))
         if len(win.screen.group) == 1:
-            win.response(None, Gtk.ResponseType.OK)
+            callback([
+                    (r.id, r.value.get('rec_name', ''))
+                    for r in win.screen.group])
+            win.destroy()
         else:
             win.show()
 
